@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.22.0";
+our $VERSION = "v0.23.0";
 
 1;
 __END__
@@ -100,7 +100,7 @@ RxPerl - an implementation of Reactive Extensions / rxjs for Perl
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 36 of the 100+ operators in rxjs are implemented in this module.
+Currently 40 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -125,6 +125,16 @@ should apply to RxPerl too).
 
 =over
 
+=item rx_combine_latest
+
+L<https://rxjs.dev/api/index/function/combineLatest>
+
+    # [0, 0], [0, 1], [1, 1], [1, 2], [1, 3], ...
+    rx_combine_latest([
+        rx_interval(1),
+        rx_interval(0.7),
+    ])->subscribe($observer);
+
 =item rx_concat
 
 L<https://rxjs.dev/api/index/function/concat>
@@ -214,7 +224,7 @@ Works like rxjs's "interval", except the parameter is in seconds instead of ms.
 
 L<https://rxjs.dev/api/index/function/merge>
 
-    # 0, 0, 1, 1, 2, 2, 3, 4, 3, ...
+    # 0, 0, 1, 1, 2, 3, 2, 4, 3, ...
     rx_merge(
         rx_interval(0.7),
         rx_interval(1),
@@ -315,6 +325,15 @@ L<https://rxjs.dev/api/operators/concatMap>
         }),
     )->subscribe($observer);
 
+=item op_debounce_time
+
+L<https://rxjs.dev/api/operators/debounceTime>
+
+    # 3, complete
+    rx_of(1, 2, 3)->pipe(
+        op_debounce_time(0.5),
+    )->subscribe($observer);
+
 =item op_delay
 
 L<https://rxjs.dev/api/operators/delay>
@@ -359,6 +378,15 @@ L<https://rxjs.dev/api/operators/distinctUntilKeyChanged>
         op_distinct_until_key_changed('name'),
     )->subscribe($observer);
 
+=item op_end_with
+
+L<https://rxjs.dev/api/operators/endWith>
+
+    # 0, 1, 2, 3, 100, 200, complete
+    rx_of(0, 1, 2, 3)->pipe(
+        op_end_with(100, 200),
+    )->subscribe($observer);
+
 =item op_exhaust_map
 
 L<https://rxjs.dev/api/operators/exhaustMap>
@@ -435,6 +463,21 @@ L<https://rxjs.dev/api/operators/pairwise>
         op_pairwise,
     )->subscribe(sub {print Dumper($_[0])});
 
+=item op_pluck
+
+L<https://rxjs.dev/api/operators/pluck>
+
+    # Mary, Paul, undef, undef, undef
+    rx_of(
+        {name => {first => 'Mary'}},
+        {name => {first => 'Paul'}},
+        {house => {first => 'Chicago'}},
+        15,
+        undef,
+    )->pipe(
+        op_pluck('name', 'first'),
+    )->subscribe($observer);
+
 =item op_ref_count
 
 L<https://rxjs.dev/api/operators/refCount>
