@@ -12,14 +12,89 @@ use Scalar::Util 'weaken', 'blessed';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    rx_observable rx_of rx_concat rx_defer rx_EMPTY rx_from_event
-    rx_from_event_array rx_interval rx_merge rx_NEVER rx_race
+    rx_observable rx_combine_latest rx_concat rx_defer rx_EMPTY rx_from_event
+    rx_from_event_array rx_interval rx_merge rx_NEVER rx_of rx_race
     rx_subject rx_throw_error rx_timer rx_from
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 sub rx_observable;
 
+=pod
+
+    Q: When do we subscribe to all the sources?
+
+    A: At the beginning
+
+
+    Q: When does the subscriber receive a 'next' event?
+
+    A: When (a) all the sources have emitted at least one 'next' event
+        (even now, with this emission), and (b) an event is emitted
+
+
+    Q: When does the subscriber receive an 'error' event?
+
+    A: When any of the sources emits an error.
+
+
+    Q: When does the subscriber receive a 'complete'?
+
+    A: When all of the sources have emitted 'complete'.
+
+
+    Q: What happens when the user unsubscribes?
+
+    A: We unsubscribe from all of the sources.
+
+=cut
+
+sub rx_combine_latest {
+    my ($sources) = @_;
+
+    return rx_observable->new(sub {
+        my ($subscriber) = @_;
+
+        my %own_subscriptions;
+        my $i = 0;
+        my %didnt_emit = map {($i++, 1)} @$sources;
+        my @latest_values;
+        my $num_active = @$sources;
+
+        get_subscription_from_subscriber($subscriber)->add_dependents(\%own_subscriptions);
+
+        for (my $i = 0; $i < @$sources; $i++) {
+            my $j = $i;
+            my $source = $sources->[$j];
+            my $own_subscription = RxPerl::Subscription->new;
+            $own_subscriptions{$own_subscription} = $own_subscription;
+            my $own_observer = {
+                new_subscription => $own_subscription,
+                next             => sub {
+                    my ($value) = @_;
+
+                    $latest_values[$j] = $value;
+                    delete $didnt_emit{$j};
+
+                    if (!%didnt_emit) {
+                        $subscriber->{next}->(\@latest_values) if defined $subscriber->{next};
+                    }
+                },
+                error            => $subscriber->{error},
+                complete         => sub {
+                    $num_active--;
+                    if ($num_active == 0) {
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                    }
+                },
+            };
+            $source->subscribe($own_observer);
+        }
+
+        return;
+    });
+}
+
 sub _rx_concat_helper {
     my ($sources, $subscriber, $active) = @_;
 
